function out= NonLin_Vehi_Dynamics(x,Twi,f,Td)              % Non-Linear Spacecraft Model
global J JI Iw Cw2b cg nt Jloc Jdir CB2L wo
% State Variables (x):
% x(1-3)  = Body rates (wb)   (rad/sec)
% x(4-6)  = Wheel rates rel to s/c (wr) (rad/sec)
% x(7-9)  = Reaction Wheel (i) Momentum (hwi) (ft-lb-sec)
% Inputs :
% Twi(3)  = Reaction Wheel (i) Torques (ft-lb)
% f(nt)   = RCS Forces (lbf)
% Td(3)   = Disturbance Torque

xdot=zeros(9,1); wr=zeros(3,1);                             % Initialize
wb =  x(1:3);                                               % body rates (rad/sec)
the = x(4:6);                                               % LVLH Attitude vector (rad)
hwi = x(7:9);                                               % React-Wheel (i) momentum 
Hsys= J*wb + Cw2b*hwi;                                      % System Momentum (s/c+wheels)

cphi= cos(the(1)); sphi= sin(the(1));                       % Euler Angles
cthe= cos(the(2)); sthe= sin(the(2));
cpsi= cos(the(3)); spsi= sin(the(3));

c= [-sthe * cpsi; ...                                       % Gravity Gradient terms
     cphi * sthe * spsi + sphi * cthe; ...
    -sphi * sthe * spsi + cphi * cthe];

CB2L= [cpsi, -cphi*spsi,  sphi*spsi; ...                    % Body to LVLH Transform matrix
        0,    cphi,      -sphi; ...
        0,    sphi*cpsi,  cphi*cpsi]/cpsi;

% Thruster Forces and Moments
Tr= zeros(3,1);  
for i=1:nt 
    ma= Jloc(:,i) - cg;                                     % Jet moment arms (ft)
    Tr= Tr + f(i)*cross(ma,Jdir(:,i));                      % RCS Torques (ft-lb)
end                                    

xdot(1:3)= JI*(Tr +Td - Cw2b*Twi ...                        % Vehi rotational accelerat
         + 3*wo^2*cross(c,J*c) - cross(wb,Hsys) );  
wlv= CB2L*wb + [0, wo, 0]';                                 % rate of Euler rates wrt LVLH
xdot(4:6)= wlv;                                             % rate of Euler angls wrt LVLH
xdot(7:9)= Twi;                                             % rate of Reaction Wheel Momentum

for i=1:3; wr(i)= (hwi(i)/Iw) -dot(Cw2b(:,i),wb); end       % Measured Wheel Rates wrt Spacecraft
out=[xdot; wlv; Hsys; wr]; 
