% Initialize Orbital Parameters
global d2r r2d
global J JI Iw Jw Cw2b Cb2w cg eta gam Mv CB2L Hy0 wo wo2
global I11 I22 I33 I12 I32 I31 M1 M2 Hmax Tmax
global nt Thr Jloc Jdir Ts Mode
global ang_acl att_deadband kledge rate_lim low_rate_lim

d2r= pi/180; r2d=180/pi; Ts=0.1;                % Sampling Period
Mv= 50; Mode=0;                                 % Vehicle mass in (slugs)
wo= 0.00113; wo2=wo^2;                          % Orbital Rate 0.00113
wb0=[0.0, -wo, 0.0]';                           % Initial body rate= -orb.rate
wbm=sqrt(wb0'*wb0);                             % Initial body rate magnitude [0 -wo  0]'
wr0=[-0.0, 0.0, -0.0]*d2r;                      % Initial wheel rates
Hy0= -40; Hmax=10;                              % Bias pitch momentum -40, Max desat momentum
Tmax= 0.05;                                     % Max RW torque
Hco= [Hy0, 0, 0]';                              % Initial RW Momentum (center wheel is biased)
atto=[0, 0, -0]'*d2r;                           % Initial LVLH attitude
ini= [wb0; atto; Hco];                          % State Vector Initialization

J= [1045.3,  0,       19; ...                   % Moments of Inertia Matrix
    0,       641.02,  40; ...
    19,      40,      505.05]; JI=inv(J);
I11= J(1,1); I22= J(2,2); I33= J(3,3);
I12= J(1,2); I32= J(3,2); I31= J(3,1);
cg=[-0.6, 1.2, 271.5]'/12;                      % CG Location (ft)
CB2L=eye(3);                                    % Initialize Body to LVLH Transform

Tg1=(wo^2)*[I32, 0, -I12]';                     % Bias torque without Grav-Grad
Tg2=(wo^2)*[-2*I32, 3*I31, -I12]';              % Bias torque w-dot with Grav-Grad
Tg3=(wo^2)*[-4*I32, 3*I31, +I12]';              % Bias torque for the LVLH attit model

% Linear LVLH model matrices
M1=  [0,                   2*wo*I32,   wo*(I33-I22+I11)+Hy0; ...  % phi-dot
    -2*wo*I32,             0,          2*wo*I12; ...              % theta-dot
     wo*(I22-I11-I33)-Hy0, -2*wo*I12,     0];                     % psi-dot

M2=wo*[4*(I33-I22)*wo+Hy0,  3*I12*wo,           -I31*wo; ...      % phi
       4*I12*wo,            3*(I33-I11)*wo,      I32*wo; ...      % theta
      -4*I31*wo,           -3*I32*wo,      (I11-I22)*wo+Hy0];     % psi

gam= 20*d2r;                                    % React-wheel installat angles +/- 20 (deg)
Cw2b=[ 0,          0,          0;               % Wheel to Body (y,z) Transform Matrix Cw2b
       1,        +cos(gam),   cos(gam);         % Center, Left, Right Wheels
       0,        -sin(gam),   sin(gam)];        % [Tbx,Tby,Tbz]'= Cw2b*[Tw1,Tw2,Tw3]'
Cb2w= inv(Cw2b(2:3,2:3));                       % [Tw2,Tw3]'= Cb2w*[Tcy,Tcz]'

Iw= 0.08;                                       % wheel inertia (slug-ft^2)
Jw= [Iw, 0, 0;                                  % wheel inertia matrix
     0, Iw, 0;
     0, 0, Iw];
 
% RW Pitch Gain Design
ww=0.020; zet=0.8;                               % ACS bandwidth 0.025 (rad/sec)
Kq2= 2*I22*zet*ww;                               % Rate Gain
Kq1= I22*ww^2 - 3*wo2*(I11-I33);% Kq1=0.3;       % Position Gain
Kqi= 0.0005;                                     % Integral Gain

% RW Yaw Design Gains
Kr1=(0.1*I11*I33*zet^2/Hy0)*( 1+sqrt(1+((400*Hy0^2)/(zet^2*I11*I33))) ); 
Kr1=(0.1*I11*I33*zet^2/Hy0) - sqrt( ((0.01^zet^4*I11^2*I33^2)/Hy0^2)+(4*I11*I33*zet^2) );
Kr2= 0.05*Kr1;
Kr3= 0.04*zet*(Kr2-Hy0) * sqrt(abs(Hy0/(I11*I33)));

% RCS Jet Locations and Directions
nt= 7; Thr=0.05;                                 % Number of thrusters=7, Thrust (lbf)
Jdir= zeros(3,nt); Jloc=Jdir;
Jdir(:,1)= [1,  0,  0]';                         % +X Top Centr
Jdir(:,2)= [1,  0,  0]';                         % +X Bot Centr
Jdir(:,3)= [0   1,  0]';                         % +Y Front Left
Jdir(:,4)= [0  -1,  0]';                         % -Y Front Rgiht
Jdir(:,5)= [0  -1,  0]';                         % -Y Back Right
Jdir(:,6)= [0   1,  0]';                         % +Y Back Left
Jdir(:,7)= [1   0,  0]';                         % +X Mid Centr

Jloc= [-28.35, 0.0, 216.90; ...    
       -28.35, 0.0, 296.10; ...
       15.25, -17.2, 297.63; ...
       15.25, 17.2, 297.63; ...
       -21.45, 8.5, 296.10; ...
       -21.45, -8.5, 296.10; ...
       -28.35, 0.0, 257.40]'/12;

% Phase Plane Logic
ang_acl     = [1,  1,  1]*0.4;                   % 1.5
att_deadband= [1,  1,  1]*1.0;                   % 0.5
kledge      = [1,  1,  1]*1.2;
rate_lim    = [1,  1,  1]*0.2;                   % 0.8
low_rate_lim= [1,  1,  1]*0.05;                  % 0.2
