function xdot= Spacecraft_Dynamics(x,Tc,f,Td)              % Non-Linear Dynamic Model
global J JI Iw Jw cg  
global nt Thr Jloc Jdir d2r r2d CB2L wo
% State Variables (x):
% x(1-3)  = Body rates (wb)   (rad/sec)
% x(4-6)  = Wheel rates rel to s/c (wr) (rad/sec)
% Inputs :
% Tc(3)  = Reaction Wheel Control Torques in body (ft-lb)
% f(nt)  = RCS Forces (lbf)
% Td(3)  = Disturbance Torque

xdot=zeros(6,1);                                            % Initialize
wb =  x(1:3);                                               % body rates (rad/sec)
the = x(4:6);                                               % LVLH Attitude vector (rad)

cphi= cos(the(1)); sphi= sin(the(1));                       % Euler Angles
cthe= cos(the(2)); sthe= sin(the(2));
cpsi= cos(the(3)); spsi= sin(the(3));

c= [-sthe * cpsi; ...                                       % Gravity Gradient terms
     cphi * sthe * spsi + sphi * cthe; ...
    -sphi * sthe * spsi + cphi * cthe];

CB2L= [cpsi, -cphi*spsi,  sphi*spsi; ...                    % Body to LVLH Transform matrix
        0,    cphi,      -sphi; ...
        0,    sphi*cpsi,  cphi*cpsi]/cpsi;

% Thruster Forces and Moments
Tr= zeros(3,1);  
for i=1:nt 
    ma= Jloc(:,i) - cg;                                     % Jet moment arms (ft)
    Tr= Tr + f(i)*cross(ma,Jdir(:,i));                      % RCS Torques (ft-lb)
end                                    

wlv= CB2L*wb + [0, wo, 0]';                                 % rate of Euler angls wrt LVLH
xdot(1:3)= JI*(Tr +Td +Tc + 3*wo^2*cross(c,J*c) );          % Vehi rotational accelerat
xdot(4:6)= wlv;                                             % rate of Euler angls wrt LVLH
