% Initialize Orbital Parameters
global d2r r2d
global J JI Iw Jw Cw2b Cb2w cg gam Mv CB2L Hy0 wo wo2
global I11 I22 I33 I12 I32 I31 Hmax Tmax
global nt Thr Jloc Jdir Ts Mode
global ang_acl att_deadband kledge rate_lim low_rate_lim

d2r= pi/180; r2d=180/pi; Ts=0.001;             % Sampling Period
Mv= 50; Mode=0;                                 % Vehicle mass in (slugs)
wo= 0.00113; wo2=wo^2;                          % Orbital Rate 0.00113
wb0=[0.0, -wo, 0.0]';                           % Initial body rate= -orb.rate
wbm=sqrt(wb0'*wb0);                             % Initial body rate magnitude [0 -wo  0]'
wr0=[-500, 0, 0];                               % Initial wheel rates (rad/sec)
Hy0= -40; Hmax=10;                              % Bias pitch momentum -40, Max desat momentum
Tmax= 0.05;                                     % Max RW torque
atto=[0, 0, 0]'*d2r;                            % Initial LVLH attitude
ini= [wb0; atto];                               % Initial body rate and LVLH attitude
Iw= 0.08;                                       % wheel inertia (slug-ft^2)
Hco=wr0'*Iw;                                    % Initial RW Momentum (center wheel is biased)
Jw= [Iw, 0, 0;                                  % wheel inertia matrix
     0, Iw, 0;
     0, 0, Iw];

 J= [1045.3,  0,       19; ...                  % Moments of Inertia Matrix
    0,       641.02,  40; ...
    19,      40,      505.05]; JI=inv(J);
I11= J(1,1); I22= J(2,2); I33= J(3,3);
I12= J(1,2); I32= J(3,2); I31= J(3,1);
cg=[-0.6, 1.2, 271.5]'/12;                      % CG Location (ft)
CB2L=eye(3);                                    % Initialize Body to LVLH Transform

Tg1=(wo^2)*[I32, 0, -I12]';                     % Bias torque without Grav-Grad
Tg2=(wo^2)*[-2*I32, 3*I31, -I12]';              % Bias torque w-dot with Grav-Grad
Tg3=(wo^2)*[-4*I32, 3*I31, +I12]';              % Bias torque for the LVLH attit model

gam= 20*d2r;                                    % React-wheel installat angles +/- 20 (deg)
Cw2b=[ 0,          0,          0;               % Wheel to Body (y,z) Transform Matrix Cw2b
       1,        +cos(gam),   cos(gam);         % Center, Left, Right Wheels
       0,        -sin(gam),   sin(gam)];        % [Tbx,Tby,Tbz]'= Cw2b*[Tw1,Tw2,Tw3]'
Cb2w= inv(Cw2b(2:3,2:3));                       % [Tw2,Tw3]'= Cb2w*[Tcy,Tcz]'

% RW Pitch Gain Design
ww=0.020; zet=0.8;                               % ACS bandwidth 0.025 (rad/sec)
Kq2= 2*I22*zet*ww;                               % Rate Gain
Kq1= I22*ww^2 - 3*wo2*(I11-I33);% Kq1=0.3;       % Position Gain
Kqi= 0.0005;                                     % Integral Gain

% RW Yaw Design Gains
Kr1=(0.1*I11*I33*zet^2/Hy0)*( 1+sqrt(1+((400*Hy0^2)/(zet^2*I11*I33))) ); 
Kr1=(0.1*I11*I33*zet^2/Hy0) - sqrt( ((0.01^zet^4*I11^2*I33^2)/Hy0^2)+(4*I11*I33*zet^2) );
Kr2= 0.05*Kr1;
Kr3= 0.04*zet*(Kr2-Hy0) * sqrt(abs(Hy0/(I11*I33)));

% RCS Jet Locations and Directions
nt= 7; Thr=0.05;                                 % Number of thrusters=7, Thrust (lbf)
Jdir= zeros(3,nt); Jloc=Jdir;
Jdir(:,1)= [1,  0,  0]';                         % +X Top Centr
Jdir(:,2)= [1,  0,  0]';                         % +X Bot Centr
Jdir(:,3)= [0   1,  0]';                         % +Y Front Left
Jdir(:,4)= [0  -1,  0]';                         % -Y Front Rgiht
Jdir(:,5)= [0  -1,  0]';                         % -Y Back Right
Jdir(:,6)= [0   1,  0]';                         % +Y Back Left
Jdir(:,7)= [1   0,  0]';                         % +X Mid Centr

Jloc= [-28.35, 0.0, 216.90; ...    
       -28.35, 0.0, 296.10; ...
       15.25, -17.2, 297.63; ...
       15.25, 17.2, 297.63; ...
       -21.45, 8.5, 296.10; ...
       -21.45, -8.5, 296.10; ...
       -28.35, 0.0, 257.40]'/12;

% Phase Plane Logic
ang_acl     = [1,  1,  1]*0.4;                   % 1.5
att_deadband= [1,  1,  1]*1.0;                   % 0.5
kledge      = [1,  1,  1]*1.2;
rate_lim    = [1,  1,  1]*0.2;                   % 0.8
low_rate_lim= [1,  1,  1]*0.05;                  % 0.2

[Avf, Bvf, Cvf, Dvf]= flex61;                    %  Load Flex Vehicle Model from Flixan
Iel=6.395; Iaz=1.89; Isa=3.17;                   %  Sensor Azimth, Elevat, Solar Array Inertias
omp=1; oms=0.2;                                  %  Bandwidths: Payload, Solar Array

% Compute Control System Gains
Kp4=Iel*omp*omp; Kr4=2*0.65*omp*Iel;             %.. Elevat. Gimbal Gains
Kp5=Iaz*omp*omp; Kr5=2*0.65*omp*Iaz;             %.. Azimuth Gimbal Gains
Kp6=Isa*oms*oms; Kr6=2*0.65*oms*Isa;             %.. Array Gimbal Gains

% Design a Roll Filter
H = tf( {[0.5^2]} , {[1 0.5 0.5^2]});            % 2nd order Low-Pass 0.5 (rad/sec)
HD=c2d(H,Ts,'zoh');                              % Discretize Filter
[num,den]=tfdata(HD,'v');