% Multi-Body Program Dynamics Initialization
global r1 r2 r3 b2 b3 c1 c2 c3 J1 J2 J3 M0 M3 m0 m3 m4 s0 s3 s4
global I0 I3 I4 h3ax3 h4ax4 eta3 eta4 d3 d4 Ig Ig_inv c0
global C03i C34i C04i C03 C34 J A44 A33 

% Initialization
Wbod= [1260.0,    155.0,    5.0,   65.0];                % Weights : B1, SA, Yok, PL (lb)
CGbod= [-0.05,    -0.375,   0.1,    0.1; ...             % CG locat: B1, SA, Yok, PL (ft)
        0.1,      -0.0,     0.22,   0.35; ...            % 0.1,      -0.0,     0.1,   0.1
        22.62,     17.1,    25.7,  25.8];                % 22.62,     17.1,    25.9,  25.9
Jbod1=[415,     0,     25; ...                           % Main s/c Body 1 cg Inertia 
        0,      520    14; ...                           % 0,      423    -7.6
        25,     14,    76];                              % 24.7,  -7.6,    76
Jbod2= [2*78.62+289,   0.0,    0.0; ...                  % Two Solar Arrays cg Inertia
        0.0,         4.2,     -0.2; ...
        0.0,        -0.2,     2*79.7+289];
Jbod3= [0.25,  0,    0; ...                              % Elevation Yoke
        0,     0.3,  0; ...
        0,     0,    0.3];
Jbod4= [4.9,     0.0,    0; ...                          % Telescope 6.39, 1.89, 1.15
        0.0,     1.2,    0; ...
        0,        0,     1.15];

% Individual Masses
m0a= Wbod(1)/32.174;              % Flight Vehicle
m1 = Wbod(2)/32.174;              % Solar Array
m3 = Wbod(3)/32.174;              % Gimbal Yoke (1)
m4 = Wbod(4)/32.174;              % Gimbal Optical (2)
m0 = m0a+m1;                      % Combined vehicle SA mass

C0E= eye(3);                      % ECI to Basic Coordinate Transform
C03i= eye(3); C30i=C03i';         % Initial Transform from body (3) to (0)
C34i= eye(3);                     % Initial Transform from body (4) to (3)
C04i= C03i*C34i; C40i=C04i';      % Initial Transform from body (4) to (0)
S2LOS= [1 0 0; 0 1 0; 0 0 1];     % Structures to LOS Transform
S2FV= [1; 1; 1];                  % Axis Transforms

% Initial CM locations of 3 bodies in basic coordinates
r0a = S2FV.*CGbod(:,1);           % B1 (feet)
r1  = S2FV.*CGbod(:,2);           % SA (feet)
r3  = S2FV.*CGbod(:,3);           % G1 (feet)
r4  = S2FV.*CGbod(:,4);           % G2 (feet)
r0  = (m0a*r0a + m1*r1)/m0;       % Initial combined cm FV+SA (ft)
r0x = skew(r0);

% Inertias of individual bodies relative to component cg in basic
%Imod= [1 -1 -1; -1  1 -1; -1 -1  1];
Imod= [1  1  1;  1  1  1;  1  1  1];
I0a=Jbod1;                        % FV Inertia (slug-ft^2)
I1= Jbod2.*Imod;                  % SA
I0= (I0a-m0a*skew(r0a)*skew(r0a)) + (I1-m1*skew(r1)*skew(r1)) + (m0*r0x*r0x);
J3= Jbod3.*Imod;                  % Yoke
J4= Jbod4.*Imod;                  % Cylinder

% Hinge Locations in Basic Coordinates Frame
eta3= S2FV.*[0.1, 0.22, 25]'; % Elevation Pivot
eta4= S2FV.*[0.1, 0.35, 25.2]'; % Azimuth Pivot

% CM of body i location from hinge (in body i frame)
s0 = r0;
s3 = C03i'*(r3-eta3);
s4 = C04i'*(r4-eta4);

% Hinge Location in local frame
d3 = eta3;
d4 = C03i'*(eta4-eta3);

% Hinge axes in local frame
h3ax3 = [1  0  0]';                      % Elevation Gimbal
h4ax4 = [0 -1  0]';                      % Azimuth Gimbal

% Initial Gimbal Angles (rad)
the1=0; the3=0; the4=0;

% Convert Inertias to local frames
J3 = C03i*J3*C03i; 
J4 = C04i*J4*C04i; 

% Calculate System Mass
M0= m0 + m3 + m4; M3=m3+m4;

% Initial Conditions (rad/sec)
w0= [0 0 0]'*(pi/180);
the3dot= 0*(pi/180);
the4dot= 0*(pi/180);

% Inertias about local CG in local frames
I3 = C30i*J3*C03i;
I4 = C40i*J4*C04i;

% Calculate the Subsystem cm from its parent hinge
c0 = (m0*r0 + m3*r3 + m4*r4)/M0;
c3 = (1/(m3+m4)) * (m3*r3 + m4*r4 - (m3+m4)*eta3);
c4 = r4-eta4;

% Set Initial Conditions for Dynamic Mask
C0Einit=eye(3); theinit=[0 0]; pinit=[0 0 0 0 0];
C03=C03i; C34=C34i;

% Inertia Gain Matrix
c0x = skew(c0); c3x = skew(c3); c4x = skew(c4);
r0x = skew(r0); r3x = skew(r3); r4x = skew(r4);
Ig = (I0 - m0*r0x*r0x) + M0*c0x*c0x + ...
    (C03i*I3*C30i-m3*r3x*r3x) + (C04i*I4*C40i-m4*r4x*r4x);
Ig_inv= inv(Ig);