function out= Vehi_3B3W(u,fj,Tw,Tg,Tdst)
global M0 M3 m0 m3 m4 s0 s3 s4 I0 I3 I4 Ig h3ax3 h4ax4 eta3 eta4 d3 d4 
global C03i C34i C04i C03 C34 J A44 A33 
global Worb Cb2w Cw2b Iw Jw Jw_inv d2r r2d 
global cg nt Thr Jloc Jdir

%  States:
%    u(1:4)     Bus quaternion (q)
%    u(5:6)     Gimbal Angles (the3, the4)
%    u(7:11)    System Angular Momentum (p) = [h0 h3 h4]
%    u(12:14)   Wheel rates (wr)
%    u(15:17)   Linear Momentum (mv) in ECI
%    u(18:20)   Vehicle Position in ECI (ft)

%  Inputs:
%    fj(nt)     RCS Forces for (nt) jets
%    Tw(3)      Reaction Wheel Torques (wheel axes)
%    Tg(2)      Gimbal Hinge Torques (roll, pitch) (ft-lb)
%    Tdst(3)    Disturbance Torque (ft-lb)

%  Outputs:
%    y(1:4)     Bus Quaternion Derivative
%    y(5:6)     Gimbal Rates (roll, pitch)
%    y(7:11)    System Angular Momentum Derivative (p-dot)
%    y(12:14)   Bus angular velocity (rad/sec)
%    y(15:16)   Gimbal Relative Rates

qt= u(1:4);                                     % Vehicle ECI Quaternion
wr= u(12:14);                                   % Wheel Rates
Hrw= Cw2b*Jw*wr;                                % RW Momentum (body)
pm= u(15:17);                                   % Linear Momentum (mv) in ECI
Reci= u(18:20);                                 % Vehicle Position in ECI (ft)

% Vehicle Velocity in ECI and body
CI2B= q2cos(qt)'; CB2I=CI2B';                   % ECI to Body Transformation
Veci= pm/M0; Vb= CI2B*Veci;                     % Velocity (ECI, body)

% LVLH to Body Transformation
[QI2L,CI2L]= eci2lv(Reci,Veci); CL2I=CI2L';     % ECI to LVLH rotation
CL2B= CI2B*CI2L';                               % LVLH to Body =(CI2L*CB2I)'
Ql2e= [-QI2L(1:3); QI2L(4)];                    % Rotat. from LVLH to ECI =c2Q(CI2L')
Ql2b= qxq2(QI2L,qt);                            % Rotat. from LVLH to Body

% Compute Euler Angles in radians
theta= -asin( CL2B(1,3) );
phi= atan2( CL2B(2,3),CL2B(3,3) );
psi= atan2( CL2B(1,2),CL2B(1,1) );

% Thruster Forces and Moments
Trcs= zeros(3,1); Frcs=Trcs;
for i=1:nt 
    ma= Jloc(:,i) - cg;                                 % Jet moment arms (ft)
    Trcs= Trcs + fj(i)*cross(ma,Jdir(:,i));             % Total RCS Torque (ft-lb)
    Frcs= Frcs + fj(i)*Jdir(:,i);                       % Total RCS Force (lb)
end                                    

% Compute the Gravity Forces Grv(1:3) and Torques
Ro= sqrt(Reci(1)^2 + Reci(2)^2 + Reci(3)^2);            % Distance from earth Center
Alt= Ro-2.092566e+7;                                    % Altitude from Surface
g = 1.407698e+16/(Ro^2);                                % Acceleration due to Gravity (g)
Grv= CL2I(:,3)*g;                                       % Gravity Accelerat (x,y,z) in ECI
c3 = CL2B(:,3);                                         % Orbit Normal components in body
Tgg= 3*Worb^2*[(Ig(3,3)-Ig(2,2))*c3(2)*c3(3); ...       % Gravity Gradient Torque
              +(Ig(1,1)-Ig(3,3))*c3(3)*c3(1); ...       
              +(Ig(2,2)-Ig(1,1))*c3(1)*c3(2)];

% Update the Direction Cosine matrices [qt=u(1:4), the3=u(5), the4=u(6)]
C0E =  [u(1)^2-u(2)^2-u(3)^2+u(4)^2, 2*(u(1)*u(2)+u(3)*u(4)), 2*(u(1)*u(3)-u(2)*u(4)); ...
        2*(u(1)*u(2)-u(3)*u(4)), -u(1)^2+u(2)^2-u(3)^2+u(4)^2, 2*(u(1)*u(4)+u(2)*u(3)); ...
        2*(u(1)*u(3)+u(2)*u(4)), 2*(-u(1)*u(4)+u(2)*u(3)), -u(1)^2-u(2)^2+u(3)^2+u(4)^2];
CE0= C0E';

% Express Hinge Axes in Body 0 Frame
h3ax= C03*h3ax3;
h4ax= C03*C34*h4ax4;

C03= C03i*[1     0     0;                               % Roll Axis
      0   cos(u(5))   sin(u(5)); 
      0  -sin(u(5))   cos(u(5))]; C30= C03'; 

C34=C34i*[cos(u(6))  0   -sin(u(6));                    % Transf 3->4
          0          1     0; 
          sin(u(6))  0    cos(u(6))];    
C04= C03*C34; C40= C04';

% Calculate cm locations from central body hinge
r0  = s0;
r3  = eta3 + C03*s3;
eta4= eta3 + C03*d4;
r4  = eta4 + C04*s4;

% Calculate the subsystem cm from its parent hinge
c0 = (m0*r0 + m3*r3 + m4*r4)/M0;
c3 = (1/(m3+m4)) * (m3*r3 + m4*r4 -(m3+m4)*eta3);
c4 = r4 - eta4;

c0x = skew(c0); c3x = skew(c3); c4x = skew(c4);
r0x = skew(r0); r3x = skew(r3); r4x = skew(r4);

A00 = (I0 - m0*r0x*r0x) + ...
    (C03*I3*C30-m3*r3x*r3x) + (C04*I4*C40-m4*r4x*r4x) + M0*c0x*c0x;
r3_eta3x= skew(r3-eta3);
r4_eta3x= skew(r4-eta3);
r3_eta4x= skew(r3-eta4);
r4_eta4x= skew(r4-eta4);

A03 = (C03*I3*C30 - m3*r3x*r3_eta3x + ...
       C04*I4*C40 - m4*r4x*r4_eta3x + M3*c0x*c3x)*h3ax;
A30 = A03';
A04 = (C04*I4*C40 - m4*r4x*r4_eta4x + m4*c0x*c4x)*h4ax;
A40 = A04';

A33 = h3ax'*(C03*I3*C30 - m3*r3_eta3x*r3_eta3x + ...
     C04*I4*C40 -m4*r4_eta3x*r4_eta3x + (M3*M3/M0)*c3x*c3x)*h3ax;
A34 = h3ax'*(C04*I4*C40 -m4*r4_eta3x*r4_eta4x + (m4*M3/M0)*c3x*c4x)*h4ax;
A43 = A34';
A44 = h4ax'*(C04*I4*C40 -m4*r4_eta4x*r4_eta4x +(m4*m4/M0)*c4x*c4x)*h4ax;

% Build Systm Matrix
J = [A00 A03 A04; ...
     A30 A33 A34; ...
     A40 A43 A44];
 
% Update Velocity Vector
vel= inv(J)*u(7:11); 
w0 = vel(1:3);                     % System Angular Velocity
the3dot= vel(4);                   % Gimbal Rates
the4dot= vel(5);

% Build Differential Equations
c0dot= cross(w0,c0) + cross(the3dot*h3ax, (M3/M0)*c3) ...
                    + cross(the4dot*h4ax, (m4/M0)*c4);
r0dot= cross(w0,r0);

w3 = w0 + the3dot*h3ax;                 % Body 3,4 Rates
w4 = w0 + the3dot*h3ax + the4dot*h4ax;
c3dot= cross(w3,c3) + cross(the4dot*h4ax, (m4/M3)*c4);
r3dot= cross(w0,r3) + cross(the3dot*h3ax, r3-eta3);
eta3dot= cross(w0,eta3);
r4dot= cross(w0,r4) +cross(the4dot*h4ax,r4-eta4) +cross(the3dot*h3ax,r4-eta3);
H3= C03*I3*C30*w3 + m3*cross(r3-eta3,r3dot-c0dot) + ...
    C04*I4*C40*w4 + m4*cross(r4-eta3,r4dot-c0dot);
h3dot= Tg(1) - h3ax'*(cross(w3,H3) - cross(c3dot,M3*(eta3dot-c0dot)));
c4dot= cross(w4,c4);
eta4dot= cross(w0,eta4) + cross(the3dot*h3ax,eta4-eta3);
H4= C04*I4*C40*w4 + m4*cross(r4-eta4,r4dot-c0dot);
h4dot= Tg(2) - h4ax'*(cross(w4,H4) - cross(c4dot,m4*(eta4dot-c0dot)));

% System Angular Momentum
H0= I0*w0 + m0*cross(r0,r0dot) - M0*cross(c0,c0dot) + Cw2b*Jw*wr + ... 
    C03*I3*C30*w3 + m3*cross(r3,r3dot) + ...
    C04*I4*C40*w4 + m4*cross(r4,r4dot);
H0dot= Trcs -Cw2b*Tw +Tgg -cross(w0,H0) +Tdst;   % Spacecrft Ang. Momentum-dot
Twb = -Cw2b*Tw - cross(w0,Cw2b*Jw*wr);           % RWA Torque on Vehicle (body)

% Build Momentum Vector
% Quaternion Rates Transform matrix
B=0.5*[u(4) -u(3) u(2); u(3) u(4) -u(1); -u(2) u(1) u(4); -u(1) -u(2) -u(3)];
W= [B, zeros(4,2);  zeros(2,3), eye(2)];

% Build the Derivative Vector p=u(7:11)
wrdot= Jw_inv*Tw;                            % Stdot Wheel Accelerat (wheel frame)
qtdot= W*inv(J)*u(7:11);                     % Stdot [qdot, the3dot, the4dot]
pdot= [H0dot; h3dot; h4dot];                 % Stdot [angular momentum rate]
magH= sqrt(u(7)^2 +u(8)^2 +u(9)^2);          % Magnitude of Ang. Mom.

% Translation Dynamics (ECI)
xdot(1:3)= CB2I*Frcs + Grv*M0;               % Linear Momentum (pm-dot) in ECI
xdot(4:6)= pm/M0;                            % Velocity (eci)
alfa= r2d*atan2(Vb(3),Vb(1));                % Angles of Attack, Sideslip
beta= r2d*asin(Vb(2)/sqrt(Vb'*Vb));

out= [qtdot; pdot; wrdot; xdot'; ...         % States [6, 5, 3, 6]= 20
    w0; the3dot;the4dot; u(5:6); magH; ...   % VehRat(3) GimbRat(2) GimbPos(2) mH(1)= 8
    H0; w3(1); w4(2); ...                    % Syst Momentum (3), Inert Rate(2)= 5
    Alt; Reci; Veci; Hrw; phi;theta;psi; ... % [1, 3, 3, 3, 3]= 13
    alfa;beta; Twb];                         % [2, 3]= 5