function [pos,vel,Worb,ecc]= orbitic(ap,par,ascend,angpar,incl);
% [pos,vel]= orbitic(ap,par,ascend,angpar,incl);
%
% pos    = Position (feet) at paragee 
% vel    = Velocity (ft/sec) at paragee
% ap     = apogee in (Nmiles)
% par    = paragee in (Nmiles)
% ascend = angle of ascending node (deg)
% angpar = angle to paragee (deg)
% incl   = orbit inclination (deg)

d2r=pi/180;
mu= 3.986005e5;                       % G*Earth_mass
Re= 6378.14;                          % Earth radius (km)
ap = ap*1.609344*6076.115/5280;       % apogee (km)
par=par*1.609344*6076.115/5280;       % paragee (km)
Rap= Re+ap;                           % apogee from earth center
Rpr= Re+par;                          % paragee from earth center
ecc= (Rap-Rpr)/(Rap+Rpr);             % Orbit Eccentricity
alt= 0.5*(ap+par) + Re;               % Semimajor axis
Worb= sqrt(mu/alt^3);                 % Orbit Frequency (rad/sec)
V= sqrt(mu*(2/Rpr - 1/alt));
R= zeros(3,3);
inc= incl*d2r;
Omg=ascend*d2r; 
omg=angpar*d2r; 

R(1,1)=  cos(Omg)*cos(omg) - sin(Omg)*sin(omg)*cos(inc);
R(1,2)= -cos(Omg)*sin(omg) - sin(Omg)*cos(omg)*cos(inc);
R(1,3)=  sin(Omg)*sin(inc);
R(2,1)=  sin(Omg)*cos(omg) + cos(Omg)*sin(omg)*cos(inc);
R(2,2)= -sin(Omg)*sin(omg) + cos(Omg)*cos(omg)*cos(inc);
R(2,3)= -cos(Omg)*sin(inc);
R(3,1)=  sin(omg)*sin(inc);
R(3,2)=  cos(omg)*sin(inc);
R(3,3)=  cos(inc);

pos= R*[(Re+par) 0 0]'*3280.84;      % Convert to (ft)
vel= R*[0 V 0]'*3280.84;             % Convert to (ft)