global d2r r2d
global Worb wr0 wb0 Cb2w Cw2b Iw Jw Jw_inv
global nt Thr Jloc Jdir Ts Tsr Mode
global ang_acl att_deadband kledge rate_lim low_rate_lim
global cg Mv CB2L Hy0 wo wo2
global I0 I11 I22 I33 I12 I32 I31 Tmax Hmax

% Initialize Orbital Parameters
d2r= pi/180; r2d=180/pi; Ts=0.001; Tsr=0.1;      % Sampling Period
Dynamics_Data                                    % Load Appendage Mass Properties
[Aflx, Bflx, Cflx, Dflx]= flex61;                % Load Flex + Rigid Model from Flixan
ap=215; par=215;                                 % Satellite apogee, paragee (Nmiles)
ascend=0;                                        % angle of ascending node (deg)
angpar=0;                                        % angle to paragee (deg)
incl= 10;                                        % Orbit inclination (deg)
[Pec0,Vec0,Worb,ecc]= ...
    orbitic(ap,par,ascend,angpar,incl);          % Initial ECI Position, Velocity (ft)
wo=Worb;
wo2=wo^2;                                        % Orbital Rate 0.00113
Mv= 50; Mode=0;                                  % Vehicle mass in (slugs)
Hy0= -40; Hmax=10;                               % Bias pitch momentum -40, Max desat momentum
wb0= [0.0, -wo, 0.0]';                           % Initial Body Rates (rad/sec)
wr0= [-500.0, 0.0, 0.0];                         % Initial Wheel Rates [-500, 0, 0] (rad/sec)
Tmax= 0.05;                                      % Max RW torque
Hco= [Hy0, 0, 0]';                               % Initial RW Momentum (center wheel is biased)
atto=[0, 0, -0]'*d2r;                            % Initial LVLH attitude
ini= [wb0; atto; Hco];                           % State Vector Initialization
h0i=I0*wb0;                                      % Initial Momentum

% Vehicle/ RW Parameters, Transform matrix Cbw
gam= 20*d2r;                                     % React-wheel installat angles +/- 20 (deg)
Cw2b= [ 0,          0,          0;               % Wheel to Body (y,z) Transform Matrix Cw2b
       1,        +cos(gam),   cos(gam);          % Center, Left, Right Wheels
       0,        -sin(gam),   sin(gam)];         % [Tbx,Tby,Tbz]'= Cw2b*[Tw1,Tw2,Tw3]'
Cb2w= inv(Cw2b(2:3,2:3));                        % [Tw2,Tw3]'= Cb2w*[Tcy,Tcz]'

Iw= 0.08;                                        % wheel inertia (slug-ft^2)
Jw= [Iw, 0, 0;                                   % wheel inertia matrix
     0, Iw, 0;
     0, 0, Iw]; Jw_inv=inv(Jw);

I11= Ig(1,1); I22= Ig(2,2); I33= Ig(3,3);
I12= Ig(1,2); I32= Ig(3,2); I31= Ig(3,1);
cg=[-0.6, 1.2, 271.5]'/12;                       % CG Location (ft)
CB2L=eye(3);                                     % Initialize Body to LVLH Transform

% RW Pitch Gain Design
ww=0.020; zet=0.8;                               % ACS bandwidth 0.025 (rad/sec)
Kq2= 2*I22*zet*ww;                               % Rate Gain
Kq1= I22*ww^2 - 3*wo2*(I11-I33);% Kq1=0.3;       % Position Gain
Kqi= 0.0005;                                     % Integral Gain

% RW Yaw Design Gains
Kr1=(0.1*I11*I33*zet^2/Hy0)*( 1+sqrt(1+((400*Hy0^2)/(zet^2*I11*I33))) ); 
Kr1=(0.1*I11*I33*zet^2/Hy0) - sqrt( ((0.01^zet^4*I11^2*I33^2)/Hy0^2)+(4*I11*I33*zet^2) );
Kr2= 0.05*Kr1;
Kr3= 0.04*zet*(Kr2-Hy0) * sqrt(abs(Hy0/(I11*I33)));

% RCS Jet Locations and Directions 
nt= 7; Thr=0.05;                                 % Number of thrusters=7, Thrust (lbf)
Jdir= zeros(3,nt); Jloc=Jdir;
Jdir(:,1)= [1,  0,  0]';                         % +X Top Centr
Jdir(:,2)= [1,  0,  0]';                         % +X Bot Centr
Jdir(:,3)= [0   1,  0]';                         % +Y Front Left
Jdir(:,4)= [0  -1,  0]';                         % -Y Front Rgiht
Jdir(:,5)= [0  -1,  0]';                         % -Y Back Right
Jdir(:,6)= [0   1,  0]';                         % +Y Back Left
Jdir(:,7)= [1   0,  0]';                         % +X Mid Centr

Jloc= [-28.35, 0.0, 216.90; ...    
       -28.35, 0.0, 296.10; ...
       15.25, -17.2, 297.63; ...
       15.25, 17.2, 297.63; ...
       -21.45, 8.5, 296.10; ...
       -21.45, -8.5, 296.10; ...
       -28.35, 0.0, 257.40]'/12;

% Phase Plane Logic
ang_acl     = [1,  1,  1]*0.4;                   % 1.5
att_deadband= [1,  1,  1]*1.0;                   % 0.5
kledge      = [1,  1,  1]*1.2;
rate_lim    = [1,  1,  1]*0.2;                   % 0.8
low_rate_lim= [1,  1,  1]*0.05;                  % 0.2

% Design a Roll Filter
H = tf( {[0.5^2]} , {[1 0.5 0.5^2]});            % 2nd order Low-Pass 0.5 (rad/sec)
HD=c2d(H,Ts,'zoh');                              % Discretize Filter
[num,den]=tfdata(HD,'v');

% Initialize Quaternion
% Initial Vehicle Position= LVLH attitude
[qt1,CI2L]= eci2lv(Pec0,Vec0);                  % Initial rotation from ECI to LV
Ra=000;  Ra= Ra*pi/180;                         % Initial Veh rotat angle wrt LVLH
v= [1  0  0]'; v= v/sqrt(v'*v);                 % Initial Veh rotat vectr wrt LVLH
qr= [-v*sin(Ra/2); cos(Ra/2)];                  % Quatern of Vehicle Rotat wrt LVLH
qr2= [-qr(1:3); qr(4)];
qti= qxq2(qr, qt1);                             % Initial Rotation from ECI to body
CI2B= q2cos(qti);                               % Initial ECI to Body Transf =q2cos(qti)
qti= [-qti(1:3); qti(4)];                       % Initial LVLH to ECI rotat
CL2B= CI2B*CI2L'; Ql2b= m2q(CL2B);              % Initial LVLH to Body

% Define Attitude Command Relative to the Initial ECI Orientation or LVLH
% Commanded ECI position with respect to Initial Attitude
phi=50; u=[1 1 1]'; q2=Quan(u,phi);              % Define rotation from initial quatern qti
q3= qxq2(qti,q2);                                % Rotate qti by quatern q2
thec=acos(q3(4))*2*r2d;                         % Initial angle Comd (ECI)
com_dir=q3(1:3);                                % Command Direction 
com_dir=com_dir/sqrt(com_dir'*com_dir);         % Direction Unit Vector

% Command Vehicle position relative to Initial LVLH
phi= 50.0; u=[1 1 1]';                            % Define rotation from initial LVLH frame
q2=Quan(u,phi); q3=qxq2(qr2,q2);                % Rotate init LVLH by quatern q2
thec_lv=acos(q3(4))*2*r2d;                      % Initial angle Comd
u=q3(1:3); dir_lv=u/sqrt(u'*u);                 % Command Direction (LVLH)

% Initialize Integrators
Int_IC= [qti', 0 0, h0i(1:3)', 0 0, wr0, Vec0'*M0, Pec0'];