% Initialize Orbital Parameters
global d2r r2d Iw Jw 
global J JI cg nt Thr Jloc Jdir Ts Tmax Hmax Cw2b Cb2w
global ang_acl att_deadband kledge rate_lim low_rate_lim

d2r= pi/180; r2d=180/pi; Ts=0.01; Tsr=0.01;      % Sampling Period, Flex & Rigid
[Arb, Brb, Crb, Drb]= fv_rb;                     % Load Rig-Body Model No Gimbals      
[Agr, Bgr, Cgr, Dgr]= fv_grb;                    % Load Rigid Model with Gimbals from Flixan
[Avf, Bvf, Cvf, Dvf]= fv_60;                     % Load Flex Model with Gimbals from Flixan
Hx0=0; Hy0=-40; Hz0=0;                           % Bias pitch RW momentum
wo=0.00113; wo2=wo^2;                            % Orbital Rate 0.00113
J= [1045.3,  0,       19; ...                    % Moments of Inertia Matrix
    0,       641.02,  40; ...
    19,      40,      505.05]; JI=inv(J);
I11= J(1,1); I22= J(2,2); I33= J(3,3);
I12= J(1,2); I32= J(3,2); I31= J(3,1);
cg=[-0.6, 1.2, 271.5]'/12;                       % CG Location (ft)

% Vehicle/ RW Parameters, Transform matrix Cbw
gam= 20*d2r;                                     % React-wheel installat angles +/- 20 (deg)
Cw2b= [ 0,          0,          0;               % Wheel to Body (y,z) Transform Matrix Cw2b
       1,        +cos(gam),   cos(gam);          % Center, Left, Right Wheels
       0,        -sin(gam),   sin(gam)];         % [Tbx,Tby,Tbz]'= Cw2b*[Tw1,Tw2,Tw3]'
Cb2w= inv(Cw2b(2:3,2:3));                        % [Tw2,Tw3]'= Cb2w*[Tcy,Tcz]'

Iw= 0.08;                                        % wheel inertia (slug-ft^2)
Tmax= 0.05;                                      % Max RW torque
Hmax=10;                                         % Max momentum before Desaturat
Jw= [Iw, 0, 0;                                   % wheel inertia matrix
     0, Iw, 0;
     0, 0, Iw]; Jw_inv=inv(Jw);

% RCS Jet Locations and Directions
nt= 7; Thr=1.0;                                  % Number of Jets=7, Throttle 0-1 (Normalized)
Jdir= zeros(3,nt); Jloc=Jdir;                    % Jet Thrust Value is Included in Vehi Model
Jdir(:,1)= [1,  0,  0]';                         % +X Top Centr
Jdir(:,2)= [1,  0,  0]';                         % +X Bot Centr
Jdir(:,3)= [0   1,  0]';                         % +Y Front Left
Jdir(:,4)= [0  -1,  0]';                         % -Y Front Rgiht
Jdir(:,5)= [0  -1,  0]';                         % -Y Back Right
Jdir(:,6)= [0   1,  0]';                         % +Y Back Left
Jdir(:,7)= [1   0,  0]';                         % +X Mid Centr

Jloc= [-28.35, 0.0, 216.90; ...    
       -28.35, 0.0, 296.10; ...
       15.25, -17.2, 297.63; ...
       15.25, 17.2, 297.63; ...
       -21.45, 8.5, 296.10; ...
       -21.45, -8.5, 296.10; ...
       -28.35, 0.0, 257.40]'/12;

% RW Pitch Gain Design
ww=0.020; zet=0.8;                               % ACS bandwidth 0.025 (rad/sec)
Kq2= 2*I22*zet*ww;                               % Rate Gain
Kq1= I22*ww^2 - 3*wo2*(I11-I33);% Kq1=0.3;       % Position Gain
Kqi= 0.0005;                                     % Integral Gain

% RW Yaw Design Gains
Kr1=(0.1*I11*I33*zet^2/Hy0) - sqrt( ((0.01^zet^4*I11^2*I33^2)/Hy0^2)+(4*I11*I33*zet^2) );
Kr2= 0.05*Kr1;
Kr3= 0.04*zet*(Kr2-Hy0) * sqrt(abs(Hy0/(I11*I33)));

% Design a Roll Filter
H = tf( {[0.5^2]} , {[1 0.5 0.5^2]});            % 2nd order Low-Pass 0.5 (rad/sec)
HD=c2d(H,Ts,'zoh');                              % Discretize Filter
[num,den]=tfdata(HD,'v');

% Attitude Sensor Dynamics
H = tf( {[1.6*30 30^2]} , {[1 1.6*30 30^2]});    % 2nd order LP Sensor 30 (rad/sec)
HD=c2d(H,Ts,'zoh');                              % Discretize Sensor
[nsen,dsen]=tfdata(HD,'v');

% Phase Plane Logic
ang_acl     = [1,  1,  1]*0.5;                   % 0.4
att_deadband= [1,  1,  1]*0.5;                   % 1.0
kledge      = [1,  1,  1]*1.2;                   % 1.2
rate_lim    = [1,  1,  1]*0.2;                   % 0.2
low_rate_lim= [1,  1,  1]*0.06;                  % 0.05

Iel=6.395; Iaz=1.89; Isa=3.17;                   %  Sensor Azimth, Elevat, Solar Array Inertias
omp=1; oms=0.2;                                  %  Bandwidths: Payload, Solar Array

% Compute Control System Gains
Kp4=Iel*omp*omp; Kr4=2*0.65*omp*Iel;             %.. Elevat. Gimbal Gains
Kp5=Iaz*omp*omp; Kr5=2*0.65*omp*Iaz;             %.. Azimuth Gimbal Gains
Kp6=Isa*oms*oms; Kr6=2*0.65*oms*Isa;             %.. Array Gimbal Gains
